@@ -1,7 +1,7 @@
 /*
  * ClassroomManager.cpp - implementation of classroom-manager
  *
- * Copyright (c) 2004-2011 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
+ * Copyright (c) 2004-2016 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
  *
  * This file is part of iTALC - http://italc.sourceforge.net
  *
@@ -28,18 +28,18 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QTextStream>
 #include <QtCore/QTimer>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QCloseEvent>
-#include <QtGui/QFileDialog>
-#include <QtGui/QHeaderView>
-#include <QtGui/QInputDialog>
-#include <QtGui/QLabel>
-#include <QtGui/QMenu>
-#include <QtGui/QMessageBox>
+#include <QButtonGroup>
+#include <QCloseEvent>
+#include <QFileDialog>
+#include <QHeaderView>
+#include <QInputDialog>
+#include <QLabel>
+#include <QMenu>
+#include <QMessageBox>
 #include <QtGui/QPixmap>
-#include <QtGui/QPushButton>
-#include <QtGui/QSplashScreen>
-#include <QtGui/QSplitter>
+#include <QPushButton>
+#include <QSplashScreen>
+#include <QSplitter>
 #include <QtGui/QPainter>
 
 
@@ -51,7 +51,6 @@
 #include "ItalcConfiguration.h"
 #include "LocalSystem.h"
 #include "ToolButton.h"
-#include "DecoratedMessageBox.h"
 
 #define DEFAULT_WINDOW_WIDTH	1005
 #define DEFAULT_WINDOW_HEIGHT	700
@@ -81,7 +80,7 @@ QPixmap * classRoomItem::s_clientObservedPixmap = NULL;
 
 ClassroomManager::ClassroomManager( MainWindow * _main_window,
 							QWidget * _parent ) :
-	SideBarWidget( QPixmap( ":/resources/classroom_manager.png" ),
+	SideBarWidget( QPixmap( ":/resources/applications-education.png" ),
 			tr( "Classroom-Manager" ),
 			tr( "Use this workspace to manage your computers and "
 				"classrooms in an easy way." ),
@@ -115,10 +114,10 @@ ClassroomManager::ClassroomManager( MainWindow * _main_window,
 	m_view->setIconSize( QSize( 22, 22 ) );
 	m_view->header()->resizeSection( m_view->header()->logicalIndex( 0 ),
 									200 );
-	m_view->setSortingEnabled( TRUE );
-	m_view->setRootIsDecorated( TRUE );
+	m_view->setSortingEnabled( true );
+	m_view->setRootIsDecorated( true );
 	m_view->sortItems( 0, Qt::AscendingOrder );
-//	m_view->setShowToolTips( TRUE );
+//	m_view->setShowToolTips( true );
 	m_view->setWindowTitle( tr( "Classroom-Manager" ) );
 	m_view->setContextMenuPolicy( Qt::CustomContextMenu );
 	connect( m_view, SIGNAL( itemDoubleClicked( QTreeWidgetItem *, int ) ),
@@ -140,14 +139,14 @@ ClassroomManager::ClassroomManager( MainWindow * _main_window,
 		tr( "Use the context-menu (right mouse-button) to add/remove "
 			"computers and/or classrooms." ), contentParent() );
 	l->addWidget( help_txt );
-	help_txt->setWordWrap( TRUE );
+	help_txt->setWordWrap( true );
 	help_txt->setFont( f );
 
 	l->addSpacing( 16 );
 
 	m_exportToFileBtn = new QPushButton(
-				QPixmap( ":/resources/filesave.png" ),
-						tr( "Export to text-file" ),
+				QPixmap( ":/resources/document-save.png" ),
+						tr( "Export to text file" ),
 							contentParent() );
 	l->addWidget( m_exportToFileBtn );
 	connect( m_exportToFileBtn, SIGNAL( clicked() ),
@@ -179,7 +178,7 @@ void ClassroomManager::setupMenus()
 {
 	QAction * act;
 	QAction * separator = new QAction( this );
-	separator->setSeparator( TRUE );
+	separator->setSeparator( true );
 
 	/*** quick workspace menu ***/
 
@@ -188,12 +187,12 @@ void ClassroomManager::setupMenus()
 
 /*	m_quickSwitchMenu->addSeparator();
 
-	m_quickSwitchMenu->addAction( QPixmap( ":/resources/adjust_size.png" ),
+	m_quickSwitchMenu->addAction( QPixmap( ":/resources/zoom-fit-best.png" ),
 				tr( "Adjust windows and their size" ),
 						this, SLOT( adjustWindows() ) );
 
 	m_quickSwitchMenu->addAction(
-				QPixmap( ":/resources/auto_arrange.png" ),
+				QPixmap( ":/resources/vcs-locally-modified.png" ),
 				tr( "Auto re-arrange windows" ),
 					this, SLOT( arrangeWindows() ) );*/
 
@@ -201,29 +200,29 @@ void ClassroomManager::setupMenus()
 
 	m_classRoomItemActionGroup = new QActionGroup( this );
 
-	act = m_classRoomItemActionGroup->addAction( 
-			QPixmap( ":/resources/client_show.png" ),
+	act = m_classRoomItemActionGroup->addAction(
+			QPixmap( ":/resources/edit-find.png" ),
 			tr( "Show/hide" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( showHideClient() ) );
 
-	act = m_classRoomItemActionGroup->addAction( 
-			QPixmap( ":/resources/config.png" ),
+	act = m_classRoomItemActionGroup->addAction(
+			QPixmap( ":/resources/document-edit.png" ),
 			tr( "Edit settings" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( editClientSettings() ) );
 
 	act = m_classRoomItemActionGroup->addAction(
-			QPixmap( ":/resources/client_remove.png" ),
+			QPixmap( ":/resources/list-remove.png" ),
 			tr( "Remove" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( removeClient() ) );
 
-	m_classRoomItemActionGroup->addAction( "" )->setSeparator( TRUE );
+	m_classRoomItemActionGroup->addAction( "" )->setSeparator( true );
 
 	/*** actions for single classroom in context Menu ***/
 
 	m_classRoomActionGroup = new QActionGroup( this );
 
 	act = m_classRoomActionGroup->addAction(
-			QPixmap( ":/resources/classroom_show.png" ),
+			QPixmap( ":/resources/edit-find.png" ),
 			tr( "Show all computers in classroom" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( showSelectedClassRooms() ) );
 
@@ -233,40 +232,40 @@ void ClassroomManager::setupMenus()
 	connect( act, SIGNAL( triggered() ), this, SLOT( hideSelectedClassRooms() ) );
 
 	act = m_classRoomActionGroup->addAction(
-			QPixmap( ":/resources/no_user.png" ),
+			QPixmap( ":/resources/preferences-system-login.png" ),
 			tr( "Hide teacher computers" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( hideTeacherClients() ) );
 
 	act = m_classRoomActionGroup->addAction(
-			QPixmap( ":/resources/config.png" ),
+			QPixmap( ":/resources/document-edit.png" ),
 			tr( "Edit name" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( editClassRoomName() ) );
 
 	act = m_classRoomActionGroup->addAction(
-			QPixmap( ":/resources/classroom_remove.png" ),
+			QPixmap( ":/resources/edit-delete.png" ),
 			tr("Remove classroom" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( removeClassRoom() ) );
 
-	m_classRoomActionGroup->addAction( "" )->setSeparator( TRUE );
+	m_classRoomActionGroup->addAction( "" )->setSeparator( true );
 
 	/*** common actions in context menu ***/
 
 	m_contextActionGroup = new QActionGroup( this );
 
 	act = m_contextActionGroup->addAction(
-			QPixmap( ":/resources/client_add.png" ),
+			QPixmap( ":/resources/list-add.png" ),
 			tr( "Add computer" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( addClient() ) );
 
 	act = m_contextActionGroup->addAction(
-			QPixmap( ":/resources/classroom_add.png" ),
+			QPixmap( ":/resources/folder-add.png" ),
 			tr( "Add classroom" ) );
 	connect( act, SIGNAL( triggered() ), this, SLOT( addClassRoom() ) );
 
 	/*** Default client Menu ***/
 
 	m_clientMenu = clientMenu::createDefault( this );
-	
+
 }
 
 
@@ -318,11 +317,11 @@ void ClassroomManager::saveGlobalClientConfig( void )
 	for( int i = 0; i < m_view->topLevelItemCount(); ++i )
 	{
 		saveSettingsOfChildren( doc, root, m_view->topLevelItem( i ),
-									TRUE );
+									true );
 	}
 
 	QString xml = "<?xml version=\"1.0\"?>\n" + doc.toString( 2 );
-/*	if( MainWindow::ensureConfigPathExists() == FALSE )
+/*	if( MainWindow::ensureConfigPathExists() == false )
 	{
 		qFatal( QString( "Could not read/write or create directory %1!"
 					"For running iTALC, make sure you have "
@@ -362,7 +361,7 @@ void ClassroomManager::savePersonalConfig( void )
 	globalsettings.setAttribute( "win-width", mainWindow()->width() );
 	globalsettings.setAttribute( "win-height", mainWindow()->height() );
 	globalsettings.setAttribute( "win-x", mainWindow()->x() );
-	globalsettings.setAttribute( "win-y", mainWindow()->y() );	
+	globalsettings.setAttribute( "win-y", mainWindow()->y() );
 	globalsettings.setAttribute( "ismaximized",
 					mainWindow()->isMaximized() );
 	globalsettings.setAttribute( "opened-tab",
@@ -411,7 +410,7 @@ void ClassroomManager::savePersonalConfig( void )
 	for( int i = 0; i < m_view->topLevelItemCount(); ++i )
 	{
 		saveSettingsOfChildren( doc, root, m_view->topLevelItem( i ),
-									FALSE );
+									false );
 	}
 
 	foreach ( QDomNode node, m_customMenuConfiguration )
@@ -478,11 +477,11 @@ void ClassroomManager::saveSettingsOfChildren( QDomDocument & _doc,
 						c->isVisible() ? "yes" : "no" );
 						client_element.setAttribute(
 			"x", QString::number( c->pos().x() ) );
- 						client_element.setAttribute(
+						client_element.setAttribute(
 			"y", QString::number( c->pos().y() ) );
 						client_element.setAttribute(
 			"w", QString::number( c->width() ) );
- 						client_element.setAttribute(
+						client_element.setAttribute(
 			"h", QString::number( c->height() ) );
 				}
 				classroom.appendChild( client_element );
@@ -595,7 +594,7 @@ mainWindow()->move( node.toElement().attribute( "win-x" ).toInt(),
 			else
 			{
 				setDefaultWindowsSizeAndPosition();
- 			}
+			}
 			if( node.toElement().attribute( "opened-tab" ) !=
 								QString::null )
 			{
@@ -649,7 +648,7 @@ mainWindow()->move( node.toElement().attribute( "win-x" ).toInt(),
 				node.toElement().attribute( "showUserColumn" ).toInt() );
 		}
 		node = node.nextSibling();
-        }
+		}
 }
 
 
@@ -660,10 +659,10 @@ void ClassroomManager::loadTree( classRoom * _parent_item,
 						bool _is_global_config )
 {
 	for( QDomNode node = _parent_element.firstChild();
-						node.isNull() == FALSE;
+						node.isNull() == false;
 						node = node.nextSibling() )
 	{
-		if( node.isElement() == FALSE )
+		if( node.isElement() == false )
 		{
 			continue;
 		}
@@ -706,7 +705,7 @@ void ClassroomManager::loadTree( classRoom * _parent_item,
 				QString nickname = e.attribute( "name" );
 
 				// add new client
-                                Client * c = new Client( hostname,
+								Client * c = new Client( hostname,
 						mac,
 						nickname,
 						(Client::Types)e.attribute(
@@ -761,7 +760,7 @@ void ClassroomManager::loadMenuElement( QDomElement _e )
 		{
 			if ( act->text() == _e.attribute( "hide" ) )
 			{
-				act->setVisible( FALSE );
+				act->setVisible( false );
 			}
 		}
 	}
@@ -769,7 +768,7 @@ void ClassroomManager::loadMenuElement( QDomElement _e )
 	{
 		QString name = _e.attribute( "remote-cmd",
 				_e.attribute( "local-cmd" ) );
-		QString icon = _e.attribute( "icon", ":resources/run.png" );
+		QString icon = _e.attribute( "icon", ":resources/run-build.png" );
 		QString before = _e.attribute( "before" );
 
 		if ( name.isEmpty() )
@@ -834,16 +833,11 @@ void ClassroomManager::loadGlobalClientConfig( void )
 		{
 			splashScreen->close();
 		}
-		DecoratedMessageBox::information(
-					tr( "No configuration-file found" ),
-					tr( "Could not open configuration "
-						"file %1.\nYou will have to "
-						"add at least one classroom "
-						"and computers using the "
-						"classroom-manager which "
-						"you'll find inside the "
-						"program in the sidebar on the "
-						"left side."
+		QMessageBox::information( this, tr( "No configuration file found" ),
+					tr( "Could not open configuration file %1. You will have to "
+						"add at least one classroom and computers using the "
+						"classroom manager which you'll find inside the program "
+						"in the sidebar on the left side."
 					).arg( m_globalClientConfiguration ) );
 		return;
 	}
@@ -856,16 +850,11 @@ void ClassroomManager::loadGlobalClientConfig( void )
 		{
 			splashScreen->close();
 		}
-		DecoratedMessageBox::information(
-					tr( "Error in configuration-file" ),
-					tr( "Error while parsing configuration-"
-						"file %1.\nPlease edit it. "
-						"Otherwise you should delete "
-						"this file and have to add all "
-						"classrooms and computers "
-						"again."
-					).arg( m_globalClientConfiguration ),
-					QPixmap( ":/resources/error.png" ) );
+		QMessageBox::critical( this, tr( "Error in configuration file" ),
+					tr( "Error while parsing configuration file %1. Please fix the "
+						"file manually. Otherwise you should delete the file and "
+						"add all classrooms and computers again." ).
+								  arg( m_globalClientConfiguration ) );
 		cfg_file.close();
 		return;
 	}
@@ -882,7 +871,7 @@ void ClassroomManager::loadGlobalClientConfig( void )
 	{
 		if( node.isElement() && node.nodeName() == "body" )
 		{
-			loadTree( NULL, node.toElement(), TRUE );
+			loadTree( NULL, node.toElement(), true );
 			break;
 		}
 		node = node.nextSibling();
@@ -895,7 +884,7 @@ void ClassroomManager::loadGlobalClientConfig( void )
 void ClassroomManager::setDefaultWindowsSizeAndPosition( void )
 {
 	mainWindow()->resize( DEFAULT_WINDOW_WIDTH, DEFAULT_WINDOW_HEIGHT );
-	mainWindow()->move( QPoint( 0, 0 ) );	
+	mainWindow()->move( QPoint( 0, 0 ) );
 }
 
 
@@ -926,14 +915,10 @@ void ClassroomManager::loadPersonalConfig( void )
 		{
 			splashScreen->close();
 		}
-		DecoratedMessageBox::information(
-					tr( "Error in configuration-file" ),
-					tr( "Error while parsing configuration-"
-						"file %1.\nPlease edit it. "
-						"Otherwise you should delete "
-						"this file."
-					).arg( m_personalConfiguration ),
-					QPixmap( ":/resources/error.png" ) );
+		QMessageBox::critical( this, tr( "Error in configuration file" ),
+					tr( "Error while parsing configuration file %1. Please fix the "
+						"file manually. Otherwise you should delete the file." ).
+					arg( m_personalConfiguration ) );
 		cfg_file.close();
 		setDefaultWindowsSizeAndPosition();
 		return;
@@ -961,7 +946,7 @@ void ClassroomManager::loadPersonalConfig( void )
 	{
 		if( node.isElement() && node.nodeName() == "body" )
 		{
-			loadTree( NULL, node.toElement(), FALSE );
+			loadTree( NULL, node.toElement(), false );
 			break;
 		}
 		node = node.nextSibling();
@@ -970,23 +955,6 @@ void ClassroomManager::loadPersonalConfig( void )
 
 
 
-
-void ClassroomManager::updateClients( void )
-{
-	QVector<Client *> vc = visibleClients();
-
-	foreach( Client * cl, vc )
-	{
-		// update current client
-		cl->update();
-	}
-
-	QTimer::singleShot( m_clientUpdateInterval, this, SLOT( updateClients() ) );
-}
-
-
-
-
 void ClassroomManager::clickedExportToFile( void )
 {
 	QString outfn = QFileDialog::getSaveFileName( this,
@@ -1397,7 +1365,7 @@ void ClassroomManager::contextMenuRequest( const QPoint & _pos )
 		contextMenu->addActions( m_classRoomActionGroup->actions() );
 	}
 	else
-	{ 
+	{
 		/* no items */
 		foreach ( classRoom * cr, m_classRooms )
 		{
@@ -1503,12 +1471,12 @@ void ClassroomManager::showHideClient( void )
 
 	if( si.size() > 0 )
 	{
-		bool all_shown = TRUE;
+		bool all_shown = true;
 		foreach( classRoomItem * cri, si )
 		{
 			if( cri->getClient()->isVisible() )
 			{
-				all_shown = FALSE;
+				all_shown = false;
 				break;
 			}
 		}
@@ -1552,7 +1520,7 @@ void ClassroomManager::removeClient( void )
 		foreach( classRoomItem * cri, si )
 		{
 			cri->getClient()->hide();
-			m_view->setItemHidden( cri, TRUE );
+			m_view->setItemHidden( cri, true );
 			m_clientsToRemove.push_back( cri->getClient() );
 		}
 	}
@@ -1565,7 +1533,7 @@ void ClassroomManager::setStateOfClassRoom( classRoom * _cr, bool _shown )
 {
 	if( _shown )
 	{
-		_cr->setMenuItemIcon( QIcon( ":/resources/greenled.png" ) );
+		_cr->setMenuItemIcon( QIcon( ":/resources/dot-green.png" ) );
 	}
 	else
 	{
@@ -1605,7 +1573,7 @@ void ClassroomManager::showSelectedClassRooms( void )
 	{
 		if( m_view->isItemSelected( cr ) && cr->childCount() )
 		{
-			setStateOfClassRoom( cr, TRUE );
+			setStateOfClassRoom( cr, true );
 		}
 	}
 }
@@ -1619,7 +1587,7 @@ void ClassroomManager::hideSelectedClassRooms( void )
 	{
 		if( m_view->isItemSelected( cr ) && ( cr )->childCount() )
 		{
-			setStateOfClassRoom( cr, FALSE );
+			setStateOfClassRoom( cr, false );
 		}
 	}
 }
@@ -1631,7 +1599,7 @@ void ClassroomManager::hideAllClassRooms( void )
 {
 	foreach( classRoom * cr, m_classRooms )
 	{
-		setStateOfClassRoom( cr, FALSE );
+		setStateOfClassRoom( cr, false );
 	}
 }
 
@@ -1642,7 +1610,7 @@ void ClassroomManager::editClassRoomName( void )
 {
 	foreach( classRoom * cr, m_classRooms )
 	{
-		if( m_view->isItemSelected( cr ) == FALSE )
+		if( m_view->isItemSelected( cr ) == false )
 		{
 			continue;
 		}
@@ -1670,7 +1638,7 @@ void ClassroomManager::removeClassRoom( void )
 {
 	foreach( classRoom * cr, m_classRooms )
 	{
-		if( m_view->isItemSelected( cr ) == FALSE )
+		if( m_view->isItemSelected( cr ) == false )
 		{
 			continue;
 		}
@@ -1694,7 +1662,7 @@ void ClassroomManager::removeClassRoom( void )
 
 void ClassroomManager::removeClassRoom( classRoom * cr )
 {
-		m_view->setItemHidden( cr, TRUE );
+		m_view->setItemHidden( cr, true );
 
 		for ( int i = 0 ; i < cr->childCount(); ++i )
 		{
@@ -1781,7 +1749,7 @@ void ClassroomManager::addClassRoom( void )
 
 			if ( !sel_cr && dynamic_cast<classRoomItem *>( item ) )
 			{
-				sel_cr = dynamic_cast<classRoom *>( 
+				sel_cr = dynamic_cast<classRoom *>(
 					item->parent() );
 			}
 
@@ -1854,7 +1822,7 @@ classTreeWidget::classTreeWidget( QWidget * _parent ) :
 {
 	setDragEnabled( true );
 	setAcceptDrops( true );
-	setDropIndicatorShown( true ); 
+	setDropIndicatorShown( true );
 	setDragDropMode( QAbstractItemView::InternalMove );
 
 	connect( this, SIGNAL( itemSelectionChanged( void ) ),
@@ -1879,7 +1847,7 @@ void classTreeWidget::mousePressEvent( QMouseEvent * _me )
 		if ( ! item->isSelected() )
 		{
 			clearSelection();
-			item->setSelected( TRUE );
+			item->setSelected( true );
 		}
 	}
 
@@ -1891,7 +1859,7 @@ void classTreeWidget::mousePressEvent( QMouseEvent * _me )
 
 void classTreeWidget::mouseMoveEvent( QMouseEvent * _me )
 {
-	if ( m_clientPressed ) 
+	if ( m_clientPressed )
 	{
 		m_clientPressed->zoomBack();
 		m_clientPressed = NULL;
@@ -1905,7 +1873,7 @@ void classTreeWidget::mouseMoveEvent( QMouseEvent * _me )
 
 void classTreeWidget::mouseReleaseEvent( QMouseEvent * _me )
 {
-	if ( m_clientPressed ) 
+	if ( m_clientPressed )
 	{
 		m_clientPressed->zoomBack();
 		m_clientPressed = NULL;
@@ -1919,14 +1887,14 @@ void classTreeWidget::mouseReleaseEvent( QMouseEvent * _me )
 
 bool classTreeWidget::droppingOnItself( QTreeWidgetItem * _target )
 {
-    QList<QTreeWidgetItem *> selected = selectedItems();
-    while ( _target )
-    {
-	    if ( selected.contains( _target ) )
-		    return true;
-	    _target = dynamic_cast<QTreeWidgetItem * >( _target->parent() );
-    }
-    return false;
+	QList<QTreeWidgetItem *> selected = selectedItems();
+	while ( _target )
+	{
+		if ( selected.contains( _target ) )
+			return true;
+		_target = dynamic_cast<QTreeWidgetItem * >( _target->parent() );
+	}
+	return false;
 }
 
 
@@ -1934,7 +1902,7 @@ bool classTreeWidget::droppingOnItself( QTreeWidgetItem * _target )
 
 void classTreeWidget::dragMoveEvent( QDragMoveEvent * _e )
 {
-	if ( _e->source() == this ) 
+	if ( _e->source() == this )
 	{
 		int clients_selected = 0;
 		foreach( QTreeWidgetItem * item, selectedItems() )
@@ -1946,7 +1914,7 @@ void classTreeWidget::dragMoveEvent( QDragMoveEvent * _e )
 		}
 
 		QTreeWidgetItem * target = itemAt( _e->pos() );
-		
+
 		/* Don't drop clients to the root nor
 		 * classroom to its own child */
 		if ( ( clients_selected && ! target ) ||
@@ -1967,9 +1935,9 @@ void classTreeWidget::dragMoveEvent( QDragMoveEvent * _e )
 
 void classTreeWidget::dropEvent( QDropEvent * _e )
 {
-    if ( _e->source() == this &&
-    	dragDropMode() == QAbstractItemView::InternalMove )
-    {
+	if ( _e->source() == this &&
+		dragDropMode() == QAbstractItemView::InternalMove )
+	{
 		QTreeWidgetItem * target = itemAt( _e->pos() );
 
 		/* Use client's parent as target */
@@ -1997,7 +1965,7 @@ void classTreeWidget::dropEvent( QDropEvent * _e )
 					takeTopLevelItem( indexOfTopLevelItem( item ) );
 				}
 
-				if ( target ) 
+				if ( target )
 				{
 					target->addChild( item );
 				}
@@ -2011,7 +1979,7 @@ void classTreeWidget::dropEvent( QDropEvent * _e )
 		setSortingEnabled( sortingEnabled );
 
 		_e->accept();
-    }
+	}
 }
 
 
@@ -2115,7 +2083,7 @@ void classRoom::clientMenuTriggered( QAction * _action )
 void classRoom::switchToClassRoom( void )
 {
 	m_classroomManager->hideAllClassRooms();
-	m_classroomManager->setStateOfClassRoom( this, TRUE );
+	m_classroomManager->setStateOfClassRoom( this, true );
 }
 
 
@@ -2129,18 +2097,18 @@ void classRoom::switchToClassRoom( void )
 
 classRoomItem::classRoomItem( Client * _client, QTreeWidgetItem * _parent ) :
 	QTreeWidgetItem( _parent, QStringList( _client->name() ) ),
-	m_visible( FALSE ),
+	m_visible( false ),
 	m_client( _client )
 {
 	if( s_clientPixmap == NULL )
 	{
-		s_clientPixmap = new QPixmap( ":/resources/client_hidden.png" );
+		s_clientPixmap = new QPixmap( ":/resources/preferences-desktop-display-gray.png" );
 	}
 
 	if( s_clientObservedPixmap == NULL )
 	{
 		s_clientObservedPixmap = new QPixmap(
-					":/resources/client_visible.png" );
+					":/resources/preferences-desktop-display-blue.png" );
 	}
 
 	setFlags( Qt::ItemIsSelectable | Qt::ItemIsDragEnabled |
@@ -2165,7 +2133,7 @@ classRoomItem::~classRoomItem()
 void classRoomItem::setVisible( const bool _obs )
 {
 	m_visible = _obs;
-	if( _obs == FALSE )
+	if( _obs == false )
 	{
 		setIcon( 0, *s_clientPixmap );
 	}
@@ -2178,9 +2146,12 @@ void classRoomItem::setVisible( const bool _obs )
 
 
 
-void classRoomItem::setUser( const QString & _name )
+void classRoomItem::setUser( const QString & user )
 {
-	setText( 2, _name );
+	//if( text( 2 ) != user )
+	{
+		setText( 2, user );
+	}
 }
 
 
