@@ -49,17 +49,17 @@
  *      messages have to be explained by comments.
  */
 
+#include <stdint.h>
 
 #if defined(WIN32) && !defined(__MINGW32__)
 #define LIBVNCSERVER_WORDS_BIGENDIAN
 #define rfbBool int
 #include <sys/timeb.h>
-#include <winsock.h>
+#include <winsock2.h>
 #undef SOCKET
 #define SOCKET int
 #else
 #include <rfb/rfbconfig.h>
-#include <rfb/rfbint.h>
 #endif
 #include <rfb/keysym.h>
 
@@ -71,17 +71,16 @@
 #endif
 #endif
 
-/* some autotool versions do not properly prefix
-   WORDS_BIGENDIAN, so do that manually */
-#ifdef WORDS_BIGENDIAN
-#define LIBVNCSERVER_WORDS_BIGENDIAN
-#endif
+#if !defined(_WIN32)
+# include <endian.h>
+# if __BYTE_ORDER == __BIG_ENDIAN
+#  define LIBVNCSERVER_WORDS_BIGENDIAN 1
+# endif
+#endif /* !_WIN32 */
 
+#define rfbMax(a,b) (((a)>(b))?(a):(b))
 #if !defined(WIN32) || defined(__MINGW32__)
 #ifndef __cplusplus
-#ifndef max
-#define max(a,b) (((a)>(b))?(a):(b))
-#endif
 #endif
 #ifdef LIBVNCSERVER_HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -112,7 +111,7 @@ typedef uint32_t in_addr_t;
 #define                INADDR_NONE     ((in_addr_t) 0xffffffff)
 #endif
 
-#define MAX_ENCODINGS 32
+#define MAX_ENCODINGS 64
 
 /*****************************************************************************
  *
@@ -869,21 +868,6 @@ typedef struct {
 
 #endif
 
-/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- * h264 - h264 encoding.  We have an rfbH264Header structure
- * giving the number of bytes following.  Finally the data follows is
- * h264 encoded frame.
- */
-
-typedef struct {
-    uint32_t nBytes;
-	uint32_t slice_type;
-	uint32_t width;
-	uint32_t height;
-} rfbH264Header;
-
-#define sz_rfbH264Header 16
-
 /*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
  * XCursor encoding. This is a special encoding used to transmit X-style
  * cursor shapes from server to clients. Note that for this encoding,
@@ -1159,7 +1143,7 @@ typedef struct _rfbFileTransferMsg {
 #define rfbRErrorCmd			0xFFFFFFFF/*  Error when a command fails on remote side (ret in "size" field) */
 
 #define sz_rfbBlockSize			8192  /*  Size of a File Transfer packet (before compression) */
-#define rfbZipDirectoryPrefix   "!UVNCDIR-\0" /*  Transfered directory are zipped in a file with this prefix. Must end with "-" */
+#define rfbZipDirectoryPrefix   "!UVNCDIR-\0" /*  Transferred directory are zipped in a file with this prefix. Must end with "-" */
 #define sz_rfbZipDirectoryPrefix 9 
 #define rfbDirPrefix			"[ "
 #define rfbDirSuffix			" ]"		
