@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ar_SA">
+<TS version="2.1" language="ar_SA">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -34,7 +34,7 @@ If you&apos;re interested in translating iTALC into your local or another langua
         <source>License</source>
         <translation>ترخيص</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>iTALC - Intelligent Teaching And Learning with Computers
 
 Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
@@ -99,7 +99,7 @@ Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
         <translation>تصدير إلى ملف نصي </translation>
     </message>
     <message>
-        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes neccessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
+        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
         <translation>استخدم هذا الزر لتصدير قائمة الحاسبات وأسماء المستخدمين الحالية إلى ملف نصي. يمكنك استخدام هذا الملف لاحقا لجمع الملفات بعد إنتهاء الإختبار. يكون هذا الإجراء ضروريا، في بعض الأحيان، إذ أن بعض المستخدمين قد </translation>
     </message>
     <message>
@@ -442,6 +442,106 @@ p, li { white-space: pre-wrap; }
         <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>يرجى ملاحظة أن بعض التغييرات لن يتم تفعيلها إلا بعد إعادة تشغيل نظام &quot;آيتالك&quot;‏</translation>
     </message>
+    <message>
+        <source>Language:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>System default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ar - العربية</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cs - Česky</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>de - Deutsch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>el - Ελληνικά</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>es - Español</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fi - Suomi</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fr - Français</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>he - עִבְרִית</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>hu - Magyar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>it - Italiano</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>nl - Nederlands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>nn - Norsk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pl - Polski</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pt_br - Brasileiro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pt_pt - Português</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ru - Русский</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sk - Slovenský</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sl - Slovenčina</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sv - Svenska</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>tr - Türkçe</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>uk - Українська</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>zh_cn - 简体字</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>zh_tw - 簡體字</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfigWidget</name>
@@ -598,11 +698,11 @@ The public key part is used on the client computers to verify that any incoming
         <source>The following actions will be taken:</source>
         <translation>سيتم إتخاذ الإجراءات التالية</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Create new access keys</source>
         <translation>إنشاء مفاتيح وصول جديدة</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Import public access key from</source>
         <translation>استيراد مفتاح وصول عام من</translation>
     </message>
@@ -610,15 +710,15 @@ The public key part is used on the client computers to verify that any incoming
         <source>&lt;unknown&gt;</source>
         <translation>&lt;غير معروف&gt;</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Write access key(s) to</source>
         <translation>مفتاح أو مفاتيح الوصول إلى الكتابة إلى </translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Export public key to</source>
         <translation>تصدير مفتاح عام إلى</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Configure for user role</source>
         <translation>تهيئة دور المستخدم</translation>
     </message>
@@ -1471,7 +1571,7 @@ p, li { white-space: pre-wrap; }
         <translation>غير قادر على تسجيل الخدمة 1%‏</translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
         <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم تسجيل الخدمة 1%.‏</translation>
     </message>
     <message>
@@ -1507,11 +1607,11 @@ p, li { white-space: pre-wrap; }
         <translation>تعذر العثور على الخدمة 1% </translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
         <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم إلغاءتسجيل الخدمة 1%.‏</translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
         <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم إيقاف الخدمة 1%.‏</translation>
     </message>
     <message>
