@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sv">
+<TS version="2.1" language="sv">
 <context>
     <name>AboutDialog</name>
     <message>
         <source>About iTALC</source>
-        <translation type="unfinished">Om iTALC</translation>
+        <translation>Om iTALC</translation>
     </message>
     <message>
         <source>About</source>
-        <translation type="unfinished">Om</translation>
+        <translation>Om</translation>
     </message>
     <message>
         <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
@@ -33,7 +33,7 @@ If you&apos;re interested in translating iTALC into your local or another langua
         <source>License</source>
         <translation type="unfinished">Licens</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>iTALC - Intelligent Teaching And Learning with Computers
 
 Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
@@ -98,7 +98,7 @@ Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
         <translation>Exportera till textfil</translation>
     </message>
     <message>
-        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes neccessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
+        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
         <translation>Använd denna knapp för att exportera denna lista över datorer och användarnamn till en textfil. Du kan använda denna fil senare för att samla in filer efter ett prov har avslutats. Detta är ibland nödvändigt därför att vissa användare kanske har gjort färdigt provet tidigt och loggat ut och på sätt kan du inte samla in deras filer när provet avslutas.</translation>
     </message>
     <message>
@@ -447,6 +447,106 @@ p, li { white-space: pre-wrap; }
         <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Observera att vissa ändringar inte blir aktiva förrän du startar om iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <source>Language:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>System default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ar - العربية</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cs - Česky</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>de - Deutsch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>el - Ελληνικά</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>es - Español</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fi - Suomi</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fr - Français</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>he - עִבְרִית</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>hu - Magyar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>it - Italiano</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>nl - Nederlands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>nn - Norsk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pl - Polski</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pt_br - Brasileiro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>pt_pt - Português</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ru - Русский</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sk - Slovenský</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sl - Slovenčina</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sv - Svenska</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>tr - Türkçe</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>uk - Українська</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>zh_cn - 简体字</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>zh_tw - 簡體字</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfigWidget</name>
@@ -605,11 +705,11 @@ Den publika delen används på klientdatorerna för att verifiera att inkommande
         <source>The following actions will be taken:</source>
         <translation type="unfinished">Följande åtgärder kommer att genomföras:</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Create new access keys</source>
         <translation type="unfinished">• Skapa nya åtkomstnycklar</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Import public access key from</source>
         <translation type="unfinished">• Importera publik åtkomstnyckel från</translation>
     </message>
@@ -617,15 +717,15 @@ Den publika delen används på klientdatorerna för att verifiera att inkommande
         <source>&lt;unknown&gt;</source>
         <translation type="unfinished">&lt;okänt&gt;</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Write access key(s) to</source>
         <translation type="unfinished">• Skriv åtkomstnycklar till</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Export public key to</source>
         <translation type="unfinished">• Exportera publik nyckel till</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>• Configure for user role</source>
         <translation type="unfinished">• Konfigurera för användarrollen</translation>
     </message>
@@ -1480,7 +1580,7 @@ p, li { white-space: pre-wrap; }
         <translation>Nemôžem zaregistrovať službu &apos;%1&apos;.</translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
         <translation>Nemôžem kontaktovat Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; nebola zaregistrovaná.</translation>
     </message>
     <message>
@@ -1516,11 +1616,11 @@ p, li { white-space: pre-wrap; }
         <translation>Služba &apos;%1&apos; sa nedá nájsť.</translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
         <translation>Nemôžem kontaktovať Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; sa nedá odregistrovať.</translation>
     </message>
     <message>
-        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
+        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
         <translation>Nemôžem kontaktovať Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; nebola zastavená.</translation>
     </message>
 </context>
