@@ -1,7 +1,7 @@
 /*
  * ItalcVncConnection.cpp - implementation of ItalcVncConnection class
  *
- * Copyright (c) 2008-2014 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
+ * Copyright (c) 2008-2016 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
  *
  * This file is part of iTALC - http://italc.sourceforge.net
  *
@@ -36,6 +36,7 @@
 #include <QtCore/QCoreApplication>
 #include <QtCore/QMutexLocker>
 #include <QtCore/QTime>
+#include <QtCore/QTimer>
 
 #include <rfb/dh.h>
 
@@ -116,15 +117,18 @@ rfbBool ItalcVncConnection::hookNewClient( rfbClient *cl )
 
 	const int size = (int) cl->width * cl->height *
 					( cl->format.bitsPerPixel / 8 );
-	if( t->m_frameBuffer )
-	{
-		// do not leak if we get a new framebuffer size
-		delete [] t->m_frameBuffer;
-	}
-	t->m_frameBuffer = new uint8_t[size];
-	t->m_framebufferInitialized = false;
-	cl->frameBuffer = t->m_frameBuffer;
+
+	cl->frameBuffer = new uint8_t[size];
+
 	memset( cl->frameBuffer, '\0', size );
+
+	// initialize framebuffer image which just wraps the allocated memory and ensures cleanup after last
+	// image copy using the framebuffer gets destroyed
+	t->m_imgLock.lockForWrite();
+	t->m_image = QImage( cl->frameBuffer, cl->width, cl->height, QImage::Format_RGB32, framebufferCleanup, cl->frameBuffer );
+	t->m_imgLock.unlock();
+
+	// initialize desired framebuffer format
 	cl->format.bitsPerPixel = 32;
 	cl->format.redShift = 16;
 	cl->format.greenShift = 8;
@@ -150,7 +154,6 @@ rfbBool ItalcVncConnection::hookNewClient( rfbClient *cl )
 			cl->appData.useRemoteCursor = true;
 			break;
 		case ThumbnailQuality:
-			cl->appData.useBGR233 = 1;
 			cl->appData.encodingsString = "tight zrle ultra "
 							"copyrect hextile zlib "
 							"corre rre raw";
@@ -186,14 +189,6 @@ rfbBool ItalcVncConnection::hookNewClient( rfbClient *cl )
 
 void ItalcVncConnection::hookUpdateFB( rfbClient *cl, int x, int y, int w, int h )
 {
-	QImage img( cl->frameBuffer, cl->width, cl->height, QImage::Format_RGB32 );
-
-	if( img.isNull() )
-	{
-		qWarning( "image not loaded" );
-		return;
-	}
-
 	ItalcVncConnection * t = (ItalcVncConnection *) rfbClientGetClientData( cl, 0 );
 
 	if( t->quality() == DemoServerQuality )
@@ -202,7 +197,7 @@ void ItalcVncConnection::hookUpdateFB( rfbClient *cl, int x, int y, int w, int h
 		// color-reduction for better compression-results
 		for( int ry = y; ry < y+h; ++ry )
 		{
-			QRgb *data = ( (QRgb *) img.scanLine( ry ) );
+			QRgb *data = ( (QRgb *) t->m_image.scanLine( ry ) );
 			for( int rx = x; rx < x+w; ++rx )
 			{
 				data[rx] &= 0xfcfcfc;
@@ -210,8 +205,6 @@ void ItalcVncConnection::hookUpdateFB( rfbClient *cl, int x, int y, int w, int h
 		}
 	}
 
-	t->setImage( img );
-	t->m_framebufferInitialized = true;
 	t->imageUpdated( x, y, w, h );
 }
 
@@ -220,11 +213,12 @@ void ItalcVncConnection::hookUpdateFB( rfbClient *cl, int x, int y, int w, int h
 
 void ItalcVncConnection::hookFinishFrameBufferUpdate( rfbClient *cl )
 {
-	ItalcVncConnection *t = (ItalcVncConnection *)
-					rfbClientGetClientData( cl, 0 );
-	t->m_scaledScreenNeedsUpdate = true;
+	ItalcVncConnection *t = (ItalcVncConnection *) rfbClientGetClientData( cl, 0 );
 
-	t->framebufferUpdateComplete();
+	if( t )
+	{
+		t->finishFrameBufferUpdate();
+	}
 }
 
 
@@ -322,23 +316,37 @@ void ItalcVncConnection::hookOutputHandler( const char *format, ... )
 
 
 
+void ItalcVncConnection::framebufferCleanup( void *framebuffer )
+{
+	delete[] (uchar *) framebuffer;
+}
+
+
+
 
 ItalcVncConnection::ItalcVncConnection( QObject *parent ) :
 	QThread( parent ),
-	m_frameBuffer( NULL ),
 	m_framebufferInitialized( false ),
 	m_cl( NULL ),
 	m_italcAuthType( ItalcAuthDSA ),
 	m_quality( DemoClientQuality ),
 	m_port( PortOffsetVncServer ),
+	m_terminateTimer( this ),
 	m_framebufferUpdateInterval( 0 ),
+	m_lastFullUpdate(),
 	m_image(),
 	m_scaledScreenNeedsUpdate( false ),
 	m_scaledScreen(),
 	m_scaledSize(),
-	m_state( Disconnected ),
-	m_stopped( false )
+	m_state( Disconnected )
 {
+	m_terminateTimer.setSingleShot( true );
+	m_terminateTimer.setInterval( ThreadTerminationTimeout );
+#if QT_VERSION < 0x050400
+	connect( &m_terminateTimer, SIGNAL(timeout()), this, SLOT(terminate()) );
+#else
+	connect( &m_terminateTimer, &QTimer::timeout, this, &ItalcVncConnection::terminate );
+#endif
 }
 
 
@@ -347,29 +355,50 @@ ItalcVncConnection::~ItalcVncConnection()
 {
 	stop();
 
-	delete [] m_frameBuffer;
+	if( isRunning() )
+	{
+		qWarning( "Waiting for VNC connection thread to finish." );
+		wait( ThreadTerminationTimeout );
+	}
+
+	if( isRunning() )
+	{
+		qWarning( "Terminating hanging VNC connection thread!" );
+
+		terminate();
+		wait();
+	}
 }
 
 
 
 
-void ItalcVncConnection::stop()
+void ItalcVncConnection::stop( bool deleteAfterFinished )
 {
 	if( isRunning() )
 	{
-		m_stopped = true;
+		if( deleteAfterFinished )
+		{
+			connect( this, &ItalcVncConnection::finished,
+					 this, &ItalcVncConnection::deleteLater );
+		}
+
+		m_scaledScreen = QImage();
+
+		requestInterruption();
+
 		m_updateIntervalSleeper.wakeAll();
 
-		if( !wait( 1000 ) )
-		{
-			qWarning( "ItalcVncConnection::stop(): terminating thread" );
-			terminate();
+		// terminate thread in background after timeout
+		m_terminateTimer.start();
 
-			while( !wait( 1000 ) )
-			{
-				qWarning( "ItalcVncConnection::stop(): terminated thread is still alive!" );
-			}
-		}
+		// stop timer if thread terminates properly before timeout
+		connect( this, &ItalcVncConnection::finished,
+				 &m_terminateTimer, &QTimer::stop );
+	}
+	else if( deleteAfterFinished )
+	{
+		deleteLater();
 	}
 }
 
@@ -435,22 +464,6 @@ bool ItalcVncConnection::waitForConnected( int timeout ) const
 
 
 
-void ItalcVncConnection::setImage( const QImage & img )
-{
-	m_imgLock.lockForWrite();
-	const QSize oldSize = m_image.size();
-	m_image = img;
-	m_imgLock.unlock();
-
-	if( img.size() != oldSize )
-	{
-		emit framebufferSizeChanged( img.width(), img.height() );
-	}
-}
-
-
-
-
 const QImage ItalcVncConnection::image( int x, int y, int w, int h ) const
 {
 	QReadLocker locker( &m_imgLock );
@@ -475,26 +488,18 @@ void ItalcVncConnection::setFramebufferUpdateInterval( int interval )
 
 void ItalcVncConnection::rescaleScreen()
 {
-	if( m_scaledSize.isNull() )
+	if( m_image.size().isValid() == false ||
+			m_scaledSize.isNull() ||
+			m_framebufferInitialized == false ||
+			m_scaledScreenNeedsUpdate == false )
 	{
 		return;
 	}
 
-	if( m_scaledScreen.isNull() || m_scaledScreen.size() != m_scaledSize )
-	{
-		m_scaledScreen = QImage( m_scaledSize, QImage::Format_RGB32 );
-		m_scaledScreen.fill( Qt::black );
-	}
+	QReadLocker locker( &m_imgLock );
+	m_scaledScreen = m_image.scaled( m_scaledSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 
-	if( m_scaledScreenNeedsUpdate )
-	{
-		QReadLocker locker( &m_imgLock );
-		if( m_image.size().isValid() )
-		{
-			m_scaledScreenNeedsUpdate = false;
-			m_image.scaleTo( m_scaledScreen );
-		}
-	}
+	m_scaledScreenNeedsUpdate = false;
 }
 
 
@@ -504,15 +509,16 @@ void ItalcVncConnection::run()
 {
 	m_state = Disconnected;
 	emit stateChanged( m_state );
-	m_stopped = false;
 
 	rfbClientLog = hookOutputHandler;
 	rfbClientErr = hookOutputHandler;
 
-	while( m_stopped == false )
+	while( isInterruptionRequested() == false )
 	{
 		doConnection();
 	}
+
+	m_state = Disconnected;
 }
 
 
@@ -521,7 +527,11 @@ void ItalcVncConnection::doConnection()
 {
 	QMutex sleeperMutex;
 
-	while( !m_stopped && m_state != Connected ) // try to connect as long as the server allows
+	m_state = Connecting;
+
+	m_framebufferInitialized = false;
+
+	while( isInterruptionRequested() == false && m_state != Connected ) // try to connect as long as the server allows
 	{
 		m_cl = rfbGetClient( 8, 3, 4 );
 		m_cl->MallocFrameBuffer = hookNewClient;
@@ -588,7 +598,7 @@ void ItalcVncConnection::doConnection()
 			}
 
 			// do not sleep when already requested to stop
-			if( m_stopped )
+			if( isInterruptionRequested() )
 			{
 				break;
 			}
@@ -609,18 +619,26 @@ void ItalcVncConnection::doConnection()
 		}
 	}
 
-	//QTime lastFullUpdate = QTime::currentTime();
+	m_lastFullUpdate.restart();
 
 	// Main VNC event loop
-	while( !m_stopped )
+	while( isInterruptionRequested() == false )
 	{
+		if( m_framebufferInitialized == false )
+		{
+			// request initial full framebuffer update
+			SendFramebufferUpdateRequest( m_cl, 0, 0,
+					framebufferSize().width(), framebufferSize().height(),
+					false );
+		}
+
 		int timeout = 500;
 		if( m_framebufferUpdateInterval < 0 )
 		{
 			timeout = 100*1000;	// 100 ms
 		}
 		const int i = WaitForMessage( m_cl, timeout );
-		if( m_stopped || i < 0 )
+		if( isInterruptionRequested() || i < 0 )
 		{
 			break;
 		}
@@ -640,20 +658,16 @@ void ItalcVncConnection::doConnection()
 				break;
 			}
 		}
-		else
+
+		// ensure that we're not missing updates due to slow update rate therefore
+		// regularly request full updates
+		if( m_framebufferUpdateInterval > 0 &&
+					m_lastFullUpdate.elapsed() > 10*m_framebufferUpdateInterval )
 		{
-		/*	// work around a bug in UltraVNC on Win7 where it does not handle
-			// incremental updates correctly
-			int msecs = lastFullUpdate.msecsTo( QTime::currentTime() );
-			if( ( m_framebufferUpdateInterval > 0 &&
-					msecs > 10*m_framebufferUpdateInterval ) ||
-				( m_framebufferUpdateInterval == 0 && msecs > 1000 ) )
-			{
-				SendFramebufferUpdateRequest( m_cl, 0, 0,
-						framebufferSize().width(), framebufferSize().height(),
-						false );
-				lastFullUpdate = QTime::currentTime();
-			}*/
+			SendFramebufferUpdateRequest( m_cl, 0, 0,
+										  framebufferSize().width(), framebufferSize().height(),
+										  false );
+			m_lastFullUpdate.restart();
 		}
 
 		m_mutex.lock();
@@ -674,7 +688,7 @@ void ItalcVncConnection::doConnection()
 
 		m_mutex.unlock();
 
-		if( m_framebufferUpdateInterval > 0 && m_stopped == false )
+		if( m_framebufferUpdateInterval > 0 && isInterruptionRequested() == false )
 		{
 			sleeperMutex.lock();
 			m_updateIntervalSleeper.wait( &sleeperMutex,
@@ -689,11 +703,28 @@ void ItalcVncConnection::doConnection()
 	}
 
 	m_state = Disconnected;
+
 	emit stateChanged( m_state );
 }
 
 
 
+void ItalcVncConnection::finishFrameBufferUpdate()
+{
+	if( m_framebufferInitialized == false )
+	{
+		m_framebufferInitialized = true;
+
+		emit framebufferSizeChanged( m_image.width(), m_image.height() );
+	}
+
+	emit framebufferUpdateComplete();
+
+	m_scaledScreenNeedsUpdate = true;
+}
+
+
+
 
 void ItalcVncConnection::enqueueEvent( ClientEvent *e )
 {
