@@ -2,7 +2,7 @@
  * LocalSystem.cpp - namespace LocalSystem, providing an interface for
  *				   transparent usage of operating-system-specific functions
  *
- * Copyright (c) 2006-2012 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
+ * Copyright (c) 2006-2017 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
  *
  * This file is part of iTALC - http://italc.sourceforge.net
  *
@@ -27,13 +27,16 @@
 
 #include <QtCore/QDir>
 #include <QtCore/QProcess>
-#include <QtGui/QWidget>
+#include <QWidget>
 #include <QtNetwork/QHostInfo>
 
 
 #ifdef ITALC_BUILD_WIN32
 
+#define UNICODE
 #include <QtCore/QLibrary>
+#include <QtGui/QGuiApplication>
+#include <qpa/qplatformnativeinterface.h>
 
 #include <windows.h>
 #include <shlobj.h>
@@ -47,19 +50,19 @@ namespace LocalSystem
 {
 
 // taken from qt-win-opensource-src-4.2.2/src/corelib/io/qsettings.cpp
-QString windowsConfigPath( int _type )
+QString windowsConfigPath( int type )
 {
 	QString result;
 
 	QLibrary library( "shell32" );
-	typedef BOOL( WINAPI* GetSpecialFolderPath )( HWND, char *, int, BOOL );
+	typedef BOOL( WINAPI* GetSpecialFolderPath )( HWND, LPTSTR, int, BOOL );
 	GetSpecialFolderPath SHGetSpecialFolderPath = (GetSpecialFolderPath)
-				library.resolve( "SHGetSpecialFolderPathA" );
+				library.resolve( "SHGetSpecialFolderPathW" );
 	if( SHGetSpecialFolderPath )
 	{
-		char path[MAX_PATH];
-		SHGetSpecialFolderPath( 0, path, _type, FALSE );
-		result = QString::fromLocal8Bit( path );
+		wchar_t path[MAX_PATH];
+		SHGetSpecialFolderPath( 0, path, type, FALSE );
+		result = QString::fromWCharArray( path );
 	}
 	return( result );
 }
@@ -131,12 +134,12 @@ Desktop Desktop::activeDesktop()
 #ifdef ITALC_BUILD_WIN32
 	HDESK desktopHandle = OpenInputDesktop( 0, TRUE, DESKTOP_READOBJECTS );
 
-	char dname[256];
+	wchar_t dname[256];
 	dname[0] = 0;
 	if( GetUserObjectInformation( desktopHandle, UOI_NAME, dname,
-									sizeof( dname ), NULL ) )
+									sizeof( dname ) / sizeof( wchar_t ), NULL ) )
 	{
-		deskName = QString( "winsta0\\%1" ).arg( dname );
+		deskName = QString( "winsta0\\%1" ).arg( QString::fromWCharArray( dname ) );
 	}
 	CloseDesktop( desktopHandle );
 #endif
@@ -163,7 +166,7 @@ User::User( const QString &name, const QString &dom, const QString &fullname ) :
 #ifdef ITALC_BUILD_WIN32
 	// try to look up the user -> domain
 	DWORD sidLen = 256;
-	char domainName[MAX_PATH];
+	wchar_t domainName[MAX_PATH];
 	domainName[0] = 0;
 	char *sid = new char[sidLen];
 	DWORD domainLen = MAX_PATH;
@@ -171,7 +174,7 @@ User::User( const QString &name, const QString &dom, const QString &fullname ) :
 	m_userToken = sid;
 
 	if( !LookupAccountName( NULL,		// system name
-							m_name.toAscii().constData(),
+							(LPCWSTR) m_name.utf16(),
 							m_userToken,		// SID
 							&sidLen,
 							domainName,
@@ -184,13 +187,14 @@ User::User( const QString &name, const QString &dom, const QString &fullname ) :
 
 	if( m_domain.isEmpty() )
 	{
-		CHAR computerName[MAX_PATH];
+		wchar_t computerName[MAX_PATH];
 		DWORD size = MAX_PATH;
 		GetComputerName( computerName, &size );
 
-		if( QString( domainName ) != computerName )
+		if( QString::fromWCharArray( domainName ) !=
+			QString::fromWCharArray( computerName ) )
 		{
-			m_domain = domainName;
+			m_domain = QString::fromWCharArray( domainName );
 		}
 	}
 
@@ -269,7 +273,7 @@ static QString querySessionInformation( DWORD sessionId,
 					&pBuffer,
 					&dwBufferLen ) )
 	{
-		result = pBuffer;
+		result = QString::fromWCharArray( pBuffer );
 	}
 	WTSFreeMemory( pBuffer );
 
@@ -294,11 +298,11 @@ User User::loggedOnUser()
 	// check whether we just got the name of the local computer
 	if( !domainName.isEmpty() )
 	{
-		CHAR computerName[MAX_PATH];
+		wchar_t computerName[MAX_PATH];
 		DWORD size = MAX_PATH;
 		GetComputerName( computerName, &size );
 
-		if( domainName == computerName )
+		if( domainName == QString::fromWCharArray( computerName ) )
 		{
 			// reset domain name as storing the local computer's name
 			// doesn't help here
@@ -359,11 +363,11 @@ QString User::homePath() const
 	if( OpenProcessToken( userProcess.processHandle(),
 									MAXIMUM_ALLOWED, &hToken ) )
 	{
-		CHAR userProfile[MAX_PATH];
+		wchar_t userProfile[MAX_PATH];
 		DWORD size = MAX_PATH;
 		if( GetUserProfileDirectory( hToken, userProfile, &size ) )
 		{
-			homePath = userProfile;
+			homePath = QString::fromWCharArray( userProfile );
 			CloseHandle( hToken );
 		}
 		else
@@ -401,25 +405,26 @@ void User::lookupNameAndDomain()
 		return;
 	}
 
-	char * accName = new char[accNameLen];
-	char * domainName = new char[domainNameLen];
+	wchar_t* accName = new wchar_t[accNameLen];
+	wchar_t* domainName = new wchar_t[domainNameLen];
 	LookupAccountSid( NULL, userToken(), accName, &accNameLen,
 						domainName, &domainNameLen, &snu );
 
 	if( m_name.isEmpty() )
 	{
-		m_name = accName;
+		m_name = QString::fromWCharArray( accName );
 	}
 
 	if( m_domain.isEmpty() )
 	{
-		CHAR computerName[MAX_PATH];
+		wchar_t computerName[MAX_PATH];
 		DWORD size = MAX_PATH;
 		GetComputerName( computerName, &size );
 
-		if( QString( domainName ) != computerName )
+		if( QString::fromWCharArray( domainName ) !=
+			QString::fromWCharArray( computerName ) )
 		{
-			m_domain = domainName;
+			m_domain = QString::fromWCharArray( domainName );
 		}
 	}
 
@@ -455,43 +460,20 @@ void User::lookupFullName()
 	lookupNameAndDomain();
 
 #ifdef ITALC_BUILD_WIN32
-	char * accName = qstrdup( m_name.toAscii().constData() );
-	char * domainName = qstrdup( m_domain.toAscii().constData() );
-
 	// try to retrieve user's full name from domain
-	WCHAR wszDomain[256];
-	MultiByteToWideChar( CP_ACP, 0, domainName,
-			strlen( domainName ) + 1, wszDomain, sizeof( wszDomain ) /
-											sizeof( wszDomain[0] ) );
-	WCHAR wszUser[256];
-	MultiByteToWideChar( CP_ACP, 0, accName,
-			strlen( accName ) + 1, wszUser, sizeof( wszUser ) /
-											sizeof( wszUser[0] ) );
 
 	PBYTE dc = NULL;	// domain controller
-	if( NetGetDCName( NULL, wszDomain, &dc ) != NERR_Success )
+	if( NetGetDCName( NULL, (LPWSTR) m_domain.unicode(), &dc ) != NERR_Success )
 	{
 		dc = NULL;
 	}
 
 	LPUSER_INFO_2 pBuf = NULL;
-	NET_API_STATUS nStatus = NetUserGetInfo( (LPWSTR)dc, wszUser, 2,
+	NET_API_STATUS nStatus = NetUserGetInfo( (LPWSTR)dc, (LPWSTR) m_name.unicode(), 2,
 												(LPBYTE *) &pBuf );
 	if( nStatus == NERR_Success && pBuf != NULL )
 	{
-		int len = WideCharToMultiByte( CP_ACP, 0, pBuf->usri2_full_name,
-											-1, NULL, 0, NULL, NULL );
-		if( len > 0 )
-		{
-			char *mbstr = new char[len];
-			len = WideCharToMultiByte( CP_ACP, 0, pBuf->usri2_full_name,
-										-1, mbstr, len, NULL, NULL );
-			if( strlen( mbstr ) >= 1 )
-			{
-				m_fullName = mbstr;
-			}
-			delete[] mbstr;
-		}
+		m_fullName = QString::fromWCharArray( pBuf->usri2_full_name );
 	}
 
 	if( pBuf != NULL )
@@ -502,10 +484,6 @@ void User::lookupFullName()
 	{
 		NetApiBufferFree( dc );
 	}
-
-	delete[] accName;
-	delete[] domainName;
-
 #else
 
 #ifdef ITALC_HAVE_PWD_H
@@ -524,7 +502,7 @@ void User::lookupFullName()
 				shell.endsWith( "/null" ) ||
 				shell.endsWith( "/nologin") ) )
 		{
-			m_fullName = QString::fromUtf8( pw_entry->pw_gecos );
+			m_fullName = QString::fromUtf8( pw_entry->pw_gecos ).split( ',' ).first();
 		}
 	}
 #endif
@@ -582,7 +560,7 @@ static DWORD findProcessId_WTS( const QString &processName, DWORD sessionId,
 			continue;
 		}
 		if( processName.isEmpty() ||
-				processName.compare( pProcessInfo[proc].pProcessName,
+			processName.compare( QString::fromWCharArray( pProcessInfo[proc].pProcessName ),
 												Qt::CaseInsensitive	) == 0 )
 		{
 			if( (int) sessionId < 0 ||
@@ -635,7 +613,7 @@ static DWORD findProcessId_TH32( const QString &processName, DWORD sessionId,
 	do
 	{
 		if( processName.isEmpty() ||
-				processName.compare( procEntry.szExeFile,
+			processName.compare( QString::fromWCharArray( procEntry.szExeFile ),
 									Qt::CaseInsensitive ) == 0 )
 		{
 			if( processOwner == NULL )
@@ -740,8 +718,8 @@ Process::Handle Process::runAsUser( const QString &proc,
 									const QString &desktop )
 {
 #ifdef ITALC_BUILD_WIN32
-	enablePrivilege( SE_ASSIGNPRIMARYTOKEN_NAME, true );
-	enablePrivilege( SE_INCREASE_QUOTA_NAME, true );
+	enablePrivilege( QString::fromWCharArray( SE_ASSIGNPRIMARYTOKEN_NAME ), true );
+	enablePrivilege( QString::fromWCharArray( SE_INCREASE_QUOTA_NAME ), true );
 	HANDLE hToken = NULL;
 
 	if( !OpenProcessToken( processHandle(), MAXIMUM_ALLOWED, &hToken ) )
@@ -762,7 +740,7 @@ Process::Handle Process::runAsUser( const QString &proc,
 	si.cb = sizeof( STARTUPINFO );
 	if( !desktop.isEmpty() )
 	{
-		si.lpDesktop = (CHAR *) qstrdup( desktop.toAscii().constData() );
+		si.lpDesktop = (LPWSTR) desktop.utf16();
 	}
 	HANDLE hNewToken = NULL;
 
@@ -772,7 +750,7 @@ Process::Handle Process::runAsUser( const QString &proc,
 	if( !CreateProcessAsUser(
 				hNewToken,			// client's access token
 				NULL,			  // file to execute
-				(CHAR *) proc.toUtf8().constData(),	 // command line
+				(LPWSTR) proc.utf16(),	 // command line
 				NULL,			  // pointer to process SECURITY_ATTRIBUTES
 				NULL,			  // pointer to thread SECURITY_ATTRIBUTES
 				FALSE,			 // handles are not inheritable
@@ -787,8 +765,6 @@ Process::Handle Process::runAsUser( const QString &proc,
 		return NULL;
 	}
 
-	delete[] si.lpDesktop;
-
 	CloseHandle( hNewToken );
 	RevertToSelf();
 	CloseHandle( hToken );
@@ -842,10 +818,10 @@ bool Process::runAsAdmin( const QString &appPath, const QString &parameters )
 {
 #ifdef ITALC_BUILD_WIN32
 	SHELLEXECUTEINFO sei = { sizeof(sei) };
-	sei.lpVerb = "runas";
-	sei.lpFile = appPath.toUtf8().constData();
+	sei.lpVerb = L"runas";
+	sei.lpFile = (LPWSTR) appPath.utf16();
 	sei.hwnd = GetForegroundWindow();
-	sei.lpParameters = parameters.toUtf8().constData();
+	sei.lpParameters = (LPWSTR) parameters.utf16();
 	sei.nShow = SW_NORMAL;
 
 	if( !ShellExecuteEx( &sei ) )
@@ -886,7 +862,7 @@ void broadcastWOLPacket( const QString & _mac )
 	unsigned char mac[MAC_SIZE];
 	char out_buf[OUTBUF_SIZE];
 
-	if( sscanf( _mac.toAscii().constData(),
+	if( sscanf( _mac.toLatin1().constData(),
 				"%2x:%2x:%2x:%2x:%2x:%2x",
 				(unsigned int *) &mac[0],
 				(unsigned int *) &mac[1],
@@ -1033,8 +1009,15 @@ QString Path::shrink( QString path )
 		path.replace( QDTNS( QDir::tempPath() ), envVar.arg( "TEMP" ) );
 	}
 
-	return QDTNS( path.replace( QString( "%1%1" ).
-								arg( QDir::separator() ), QDir::separator() ) );
+	// remove duplicate directory separators - however skip the first two chars
+	// as they might specify an UNC path on Windows
+	if( path.length() > 3 )
+	{
+		return QDTNS( path.left( 2 ) + path.mid( 2 ).replace(
+									QString( "%1%1" ).arg( QDir::separator() ), QDir::separator() ) );
+	}
+
+	return QDTNS( path );
 }
 
 
@@ -1134,7 +1117,7 @@ QString Path::systemConfigDataPath()
 
 
 #ifdef ITALC_BUILD_WIN32
-BOOL enablePrivilege( LPCTSTR lpszPrivilegeName, BOOL bEnable )
+BOOL enablePrivilege( const QString& privilegeName, bool enable )
 {
 	HANDLE			hToken;
 	TOKEN_PRIVILEGES	tp;
@@ -1147,14 +1130,14 @@ BOOL enablePrivilege( LPCTSTR lpszPrivilegeName, BOOL bEnable )
 		return FALSE;
 	}
 
-	if( !LookupPrivilegeValue( NULL, lpszPrivilegeName, &luid ) )
+	if( !LookupPrivilegeValue( NULL, (LPWSTR) privilegeName.utf16(), &luid ) )
 	{
 		return FALSE;
 	}
 
 	tp.PrivilegeCount		   = 1;
 	tp.Privileges[0].Luid	   = luid;
-	tp.Privileges[0].Attributes = bEnable ? SE_PRIVILEGE_ENABLED : 0;
+	tp.Privileges[0].Attributes = enable ? SE_PRIVILEGE_ENABLED : 0;
 
 	ret = AdjustTokenPrivileges( hToken, FALSE, &tp, 0, NULL, NULL );
 
@@ -1165,15 +1148,46 @@ BOOL enablePrivilege( LPCTSTR lpszPrivilegeName, BOOL bEnable )
 #endif
 
 
-
-void activateWindow( QWidget * _w )
-{
-	_w->activateWindow();
-	_w->raise();
 #ifdef ITALC_BUILD_WIN32
-	SetWindowPos( _w->winId(), HWND_TOPMOST, 0, 0, 0, 0,
+static QWindow* windowForWidget( const QWidget* widget )
+{
+	QWindow* window = widget->windowHandle();
+	if( window )
+	{
+		return window;
+	}
+
+	const QWidget* nativeParent = widget->nativeParentWidget();
+	if( nativeParent )
+	{
+		return nativeParent->windowHandle();
+	}
+
+	return 0;
+}
+
+
+HWND getHWNDForWidget(const QWidget* widget )
+{
+	QWindow* window = windowForWidget( widget );
+	if( window )
+	{
+		QPlatformNativeInterface* interfacep = QGuiApplication::platformNativeInterface();
+		return static_cast<HWND>( interfacep->nativeResourceForWindow( QByteArrayLiteral( "handle" ), window ) );
+	}
+	return 0;
+}
+#endif
+
+
+void activateWindow( QWidget* w )
+{
+	w->activateWindow();
+	w->raise();
+#ifdef ITALC_BUILD_WIN32
+	SetWindowPos( getHWNDForWidget(w), HWND_TOPMOST, 0, 0, 0, 0,
 						SWP_NOMOVE | SWP_NOSIZE );
-	SetWindowPos( _w->winId(), HWND_NOTOPMOST, 0, 0, 0, 0,
+	SetWindowPos( getHWNDForWidget(w), HWND_NOTOPMOST, 0, 0, 0, 0,
 						SWP_NOMOVE | SWP_NOSIZE );
 #endif
 }
